@@ -38,7 +38,7 @@ class Circuit(object):
         info: information about all existing models (built-in and user-defined ones).
         deri_vari_dict: specify which attribute of which circuit element's will be calculated derivative w.r.t.
         node2ind, ind2node: information about the mapping from node's string name and node's index, and vice versa.
-        node_element: specify which circuit elements are conneted to a node.
+        node_element: specify which circuit elements are connected to a node.
         inward_node, outward_node: information about the inward and outward direction of the port of a circuit element.
 
         """
@@ -236,6 +236,7 @@ class Circuit(object):
                           node magnitude response, and 0 when calculating derivative.
         :return: the updated system matrix A and the line counter.
         """
+
         for i in range(len(outward_node)):
             A[:, line_counter, outward_node[i]] = fillconst
             A[:, line_counter, inward_node] = smatrix[:, i, :]
@@ -245,18 +246,18 @@ class Circuit(object):
     def solve(self, require_grads: Optional = True) -> Union[Tuple[np.ndarray, np.ndarray], np.ndarray]:
         """Solve the circuit port magnitude and derivative.
 
-        This function is the core of the Circuit class. The solver logic is to build a large system matrix Ax=b at one
-        frequency point, with A and b embedding all S-matrix relations of all circuit elements, and x is a (2N,1) unknown
-        vector represents the complex port magnitudes. Here N represents the number of ports, because for each port, the
-         optical signals have two propagating directions. Derivative is calculated based on a first order Taylor
-        expansion: delta_A * x + A * delta_x = 0 => delta_x = -inv(A)* delta_A * x.
-
-        In implementation, the port magnitudes and derivatives are calculated in a batch manner: all angular frequency
-        points are solved at the same time. Namely, A is of size (len(omega), 2N, 2N), etc.
+        This function is the core of the Circuit class. The solver logic is to build a large system matrix Ax=b at
+        one frequency point, with A and b embedding all S-matrix relations of all circuit elements, and x is a (2N,
+        1) unknown vector represents the complex port magnitudes. Here N represents the number of ports, because for
+        each port, the optical signals have two propagating directions. Derivative is calculated based on a first
+        order Taylor expansion: delta_A * x + A * delta_x = 0 => delta_x = -inv(A)* delta_A * x. In implementation,
+        the port magnitudes and derivatives are calculated in a batch manner: all angular frequency points are solved
+        at the same time. Namely, A is of size (len(omega), 2N, 2N), etc.
 
         :param require_grads: Whether gradient is calculated.
         :return: The port magnitude, and the gradient if needed.
         """
+
         require_grads = require_grads and self.deri_vari is not None and self.deri_node is not None \
                         and len(self.deri_vari) >= 1 and len(self.deri_node) >= 1
 
@@ -340,7 +341,7 @@ class Circuit(object):
             returned_res[i, :, 0] = response[:, 2 * node_ind, 0]
             returned_res[i, :, 1] = response[:, 2 * node_ind + 1, 0]
 
-        self.__node_signal = response # (len(omega), #nodes, 2)
+        self.__node_signal = response  # (len(omega), #nodes, 2)
 
         if not require_grads:
             return returned_res
@@ -358,17 +359,22 @@ class Circuit(object):
         """Update the attributes of the circuit
 
         Update the specified attribute with a provided new value. Since the Circuit class has both dict (even nested dict)
-        and list attributes, this function provides a convenient interface to update any attribute. Example usage:
+        and list attributes, this function provides a convenient interface to update any attribute.
+
 
-        circuit_instance.update_attr('mode_info', 4, "neff")
-        circuit_instance.update_attr('deri_node', 'n222')
-        circuit_instance.update_attr('circuit_element', ['n11', 'n222'], key_strings='tbum1::ln')
-        circuit_instance.update_attr('circuit_element', 0.3 * np.pi, key_strings='ps1::ps')
 
         :param update_attr: the attribute that will be updated.
         :param new_value: the new value of the attribute.
         :param key_string: It specify the key, if the updated attribute is a dict.
+
+        :Example:
+
+        >>> circuit_instance.update_attr('mode_info', 4, "neff")
+        >>> circuit_instance.update_attr('deri_node', 'n222')
+        >>> circuit_instance.update_attr('circuit_element', ['n11', 'n222'], key_strings='tbum1::ln')
+        >>> circuit_instance.update_attr('circuit_element', 0.3 * np.pi, key_strings='ps1::ps')
         """
+
         update_attr = update_attr.lower()
 
         cur_value = getattr(self, update_attr)
@@ -387,8 +393,10 @@ class Circuit(object):
 
         Get the current value of some attribute specified by get_attr (as well as key_strings if it exists). Example usage:
 
-        circuit_instance.get_attr('circuit_element', 'tbum1::alpha')
-        circuit_instance.get_attr('mode_info')
+        :Example:
+
+        >>> circuit_instance.get_attr('circuit_element', 'tbum1::alpha')
+        >>> circuit_instance.get_attr('mode_info')
 
         :param get_attr: specify the value of which attribute we will get.
         :param: key_strings: If the desired attribute is the value in a dict, the key needs to be provided.
