@@ -55,12 +55,9 @@ def visualize(circuit_element: dict,
     """Visualize a programmable photonics circuit containing TBUs
 
     :param circuit_element: A dict contains all TBUs and its connections
-    :param placement: a string specified the placement of the provided circuit. It will be used only if
-                      cell_place_function is None. :param
-    :param cell_place_function: A callable function, given the cell name, length and width of TBU, return the position of
-                        cell center.
+    :param placement: a string specified the placement of the provided circuit. It will be used only if cell_place_function is None.
+    :param cell_place_function: A callable function, given the cell name, length and width of TBU, return the position of cell center.
     :param kwargs: a set of parameters determining the visualization. Accepted parameters including:
-
         length_width_ratio: The ratio of TBU length over TBU width
         add_on_ratio: a tuple with two float numbers, the first for length of add-on in the 'TBU width' direction, the
                          second for length of add-on in the 'TBU length' direction.
@@ -68,9 +65,7 @@ def visualize(circuit_element: dict,
         title: the title of the figure.
         line2d_property: a dictionary with properties accepted by plt.plot()
         polygon_property: a dictionary with properties accepted by plt.fill()
-
     :return: None.
-
     """
 
     if placement == '' and cell_place_function is None:
@@ -315,4 +310,3 @@ def _visualize_base(circuit_element: dict, cell_place_func: Callable, node_signa
     if title:
         plt.title(title)
 
-    plt.show()
